@@ -1,4 +1,4 @@
-/* $Id: main.c 29350 2009-01-25 19:51:31Z nick $ */
+/* $Id: main.c 29667 2009-03-15 11:55:41Z nick $ */
 /*
  *  Copyright (c) 2008 Nick Schermer <nick@xfce.org>
  *
@@ -296,10 +296,10 @@ display_setting_refresh_rates_populate (GladeXML *gxml)
             /* get the active rate closest to the current diff */
             diff = ABS (rates[n] - XFCE_RANDR_LEGACY_RATE (xfce_randr_legacy));
 
-            /* store active*/
+            /* store active */
             if (active_diff > diff)
             {
-                active = n;
+                active = nrates - n - 1;
                 active_diff = diff;
             }
         }
